Installing velocity-tools
=========================

Requirements
------------
The following packages are required to run the code:

* astropy
* scipy
* numpy


Installation
------------
To install the latest stable release, you can type::
    
    pip install velocity-tools


Developer version
-----------------
Install by cloning locally the repository on `GitHub <https://github.com/jpinedaf/velocity_tools>`_.
If you want to install the latest developer version of the ``velocity-tools`` code, you
can do so from the git repository::

    git clone https://github.com/jpinedaf/velocity_tools.git
    cd velocity_tools
    pip install .

